/* GNOME-DB Components
 * Copyright (C) 2000-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#if !defined(__dsn_config_h__)
#  define __dsn_config_h__

#include <gtk/gtkwidget.h>

GtkWidget *dsn_config_new (void);
void       dsn_config_edit_properties (GtkWidget *dsn);
void       dsn_config_delete (GtkWidget *dsn);
void       dsn_config_select_all (GtkWidget *dsn);
void       dsn_config_unselect_all (GtkWidget *dsn);
gboolean   dsn_config_has_selection (GtkWidget *dsn);

#endif
